@@ -21,10 +21,10 @@ try:
     # For debugging purposes
     sys.path.insert(0, '../') # allows importing modules from different directory
     import TTTBoard
-    from helper import switch_player, mc_move, minimax_move
+    from helper import switch_player, mc_move, minimax_move, stop_win
 except ImportError:
     import PyCross.TTTBoard as TTTBoard
-    from PyCross.helper import switch_player, mc_move, minimax_move
+    from PyCross.helper import switch_player, mc_move, minimax_move, stop_win
 
 # Useful constants
 EMPTY = TTTBoard.EMPTY
@@ -246,12 +246,18 @@ class pycrossGUIClass:
         """
         Now Computer makes the deadly move
         """
+        move = None
+
+        if self.currdiff != 'easy': # let easy be easy
+            move = stop_win(self.board, comp) # no probability
+
         trials = randrange(self.trials, self.trials + 50) # make it difficult to predict
 
-        if len(self.board.get_empty_squares()) != 8 and trials > 750:
-            move = minimax_move(self.board, comp, trials) # just use minimax, no use of trials here
-        else:
-            move = mc_move(self.board, comp, trials)
+        if move == None:
+            if len(self.board.get_empty_squares()) != 8 and trials > 750:
+                move = minimax_move(self.board, comp, trials) # just use minimax, no use of trials here
+            else:
+                move = mc_move(self.board, comp, trials) # resort to monte-carlo method
 
         self.board.move(comp, move[0], move[1])
         return move[0], move[1]
